@@ -36,7 +36,7 @@ class OrpcConnection(object):
             password=None,
             password_hash_method=None,
             login_event=None,
-            auto_login=True,
+            auto_login=False,
             buffer_size=4096,
             rfile_buffer_size=None,
             wfile_buffer_size=None,
